@@ -9,34 +9,36 @@ The client uses WebSocket connections with AWS credentials obtained from
 the authentication flow.
 """
 
+from __future__ import annotations
+
 import asyncio
 import json
 import logging
 import uuid
 from collections.abc import Sequence
-from typing import Any, Callable, Optional
+from typing import TYPE_CHECKING, Any, Callable
 
 from awscrt import mqtt
 from awscrt.exceptions import AwsCrtError
 
-from .auth import (
-    AuthenticationError,
-    NavienAuthClient,
-    TokenRefreshError,
-)
+from .auth import NavienAuthClient
 from .events import EventEmitter
 from .exceptions import (
+    AuthenticationError,
     MqttConnectionError,
     MqttCredentialsError,
     MqttNotConnectedError,
     MqttPublishError,
+    TokenRefreshError,
 )
-from .models import (
-    Device,
-    DeviceFeature,
-    DeviceStatus,
-    EnergyUsageResponse,
-)
+
+if TYPE_CHECKING:
+    from .models import (
+        Device,
+        DeviceFeature,
+        DeviceStatus,
+        EnergyUsageResponse,
+    )
 from .mqtt_command_queue import MqttCommandQueue
 from .mqtt_connection import MqttConnection
 from .mqtt_device_control import MqttDeviceController
@@ -125,9 +127,7 @@ class NavienMqttClient(EventEmitter):
     def __init__(
         self,
         auth_client: NavienAuthClient,
-        config: Optional[MqttConnectionConfig] = None,
-        on_connection_interrupted: Optional[Callable[[Exception], None]] = None,
-        on_connection_resumed: Optional[Callable[[Any, Any], None]] = None,
+        config: MqttConnectionConfig | None = None,
     ):
         """
         Initialize the MQTT client.
@@ -135,8 +135,6 @@ class NavienMqttClient(EventEmitter):
         Args:
             auth_client: Authentication client with valid tokens
             config: Optional connection configuration
-            on_connection_interrupted: Callback for connection interruption
-            on_connection_resumed: Callback for connection resumption
 
         Raises:
             ValueError: If auth client is not authenticated or AWS
@@ -168,28 +166,24 @@ class NavienMqttClient(EventEmitter):
         self._session_id = uuid.uuid4().hex
 
         # Store event loop reference for thread-safe coroutine scheduling
-        self._loop: Optional[asyncio.AbstractEventLoop] = None
+        self._loop: asyncio.AbstractEventLoop | None = None
 
         # Initialize specialized components
         # Command queue (independent, can be created immediately)
         self._command_queue = MqttCommandQueue(config=self.config)
 
         # Components that depend on connection (initialized in connect())
-        self._connection_manager: Optional[MqttConnection] = None
-        self._reconnection_handler: Optional[MqttReconnectionHandler] = None
-        self._subscription_manager: Optional[MqttSubscriptionManager] = None
-        self._device_controller: Optional[MqttDeviceController] = None
-        self._reconnect_task: Optional[asyncio.Task[None]] = None
-        self._periodic_manager: Optional[MqttPeriodicRequestManager] = None
+        self._connection_manager: MqttConnection | None = None
+        self._reconnection_handler: MqttReconnectionHandler | None = None
+        self._subscription_manager: MqttSubscriptionManager | None = None
+        self._device_controller: MqttDeviceController | None = None
+        self._reconnect_task: asyncio.Task[None] | None = None
+        self._periodic_manager: MqttPeriodicRequestManager | None = None
 
-        # Legacy state (kept for backward compatibility during transition)
-        self._connection: Optional[mqtt.Connection] = None
+        # Connection state (simpler than checking _connection_manager)
+        self._connection: mqtt.Connection | None = None
         self._connected = False
 
-        # User-provided callbacks
-        self._on_connection_interrupted = on_connection_interrupted
-        self._on_connection_resumed = on_connection_resumed
-
         _logger.info(
             f"Initialized MQTT client with ID: {self.config.client_id}"
         )
@@ -234,19 +228,6 @@ class NavienMqttClient(EventEmitter):
         # Emit event
         self._schedule_coroutine(self.emit("connection_interrupted", error))
 
-        # Call user callback if provided
-        if self._on_connection_interrupted:
-            try:
-                self._on_connection_interrupted(error)
-            except TypeError:
-                # Fallback for callbacks expecting no arguments
-                try:
-                    self._on_connection_interrupted()  # type: ignore
-                except (TypeError, AttributeError) as e:
-                    _logger.error(
-                        f"Error in connection_interrupted callback: {e}"
-                    )
-
         # Delegate to reconnection handler if available
         if self._reconnection_handler and self.config.auto_reconnect:
             self._reconnection_handler.on_connection_interrupted(error)
@@ -266,10 +247,6 @@ class NavienMqttClient(EventEmitter):
             self.emit("connection_resumed", return_code, session_present)
         )
 
-        # Call user callback
-        if self._on_connection_resumed:
-            self._on_connection_resumed(return_code, session_present)
-
         # Delegate to reconnection handler to reset state
         if self._reconnection_handler:
             self._reconnection_handler.on_connection_resumed(
@@ -497,7 +474,7 @@ class NavienMqttClient(EventEmitter):
             success = await self._connection_manager.connect()
 
             if success:
-                # Update legacy state for backward compatibility
+                # Update connection state
                 self._connection = self._connection_manager.connection
                 self._connected = True
 
@@ -587,7 +564,7 @@ class NavienMqttClient(EventEmitter):
             # Delegate disconnection to connection manager
             await self._connection_manager.disconnect()
 
-            # Update legacy state
+            # Clear connection state
             self._connected = False
             self._connection = None
 
@@ -615,44 +592,6 @@ class NavienMqttClient(EventEmitter):
         except (AttributeError, KeyError, TypeError) as e:
             _logger.error(f"Error processing message: {e}")
 
-    def _topic_matches_pattern(self, topic: str, pattern: str) -> bool:
-        """Check if a topic matches a subscription pattern with wildcards."""
-        # Handle exact match
-        if topic == pattern:
-            return True
-
-        # Handle wildcards
-        topic_parts = topic.split("/")
-        pattern_parts = pattern.split("/")
-
-        # Multi-level wildcard # matches everything after
-        if "#" in pattern_parts:
-            hash_idx = pattern_parts.index("#")
-            # Must be at the end
-            if hash_idx != len(pattern_parts) - 1:
-                return False
-            # Topic must have at least as many parts as before the #
-            if len(topic_parts) < hash_idx:
-                return False
-            # Check parts before # with + wildcard support
-            for i in range(hash_idx):
-                if (
-                    pattern_parts[i] != "+"
-                    and topic_parts[i] != pattern_parts[i]
-                ):
-                    return False
-            return True
-
-        # Single-level wildcard + matches one level
-        if len(topic_parts) != len(pattern_parts):
-            return False
-
-        for topic_part, pattern_part in zip(topic_parts, pattern_parts):
-            if pattern_part != "+" and topic_part != pattern_part:
-                return False
-
-        return True
-
     async def subscribe(
         self,
         topic: str,
@@ -819,8 +758,8 @@ class NavienMqttClient(EventEmitter):
         Example (Traditional Callback)::
 
             >>> def on_status(status: DeviceStatus):
-            ...     print(f"Temperature: {status.dhwTemperature}°F")
-            ...     print(f"Mode: {status.operationMode}")
+            ...     print(f"Temperature: {status.dhw_temperature}°F")
+            ...     print(f"Mode: {status.operation_mode}")
             >>>
             >>> await mqtt_client.subscribe_device_status(device, on_status)
 
@@ -950,7 +889,7 @@ class NavienMqttClient(EventEmitter):
         self,
         device: Device,
         mode_id: int,
-        vacation_days: Optional[int] = None,
+        vacation_days: int | None = None,
     ) -> int:
         """
         Set DHW (Domestic Hot Water) operation mode.
@@ -1310,7 +1249,7 @@ class NavienMqttClient(EventEmitter):
     async def stop_periodic_requests(
         self,
         device: Device,
-        request_type: Optional[PeriodicRequestType] = None,
+        request_type: PeriodicRequestType | None = None,
     ) -> None:
         """
         Stop sending periodic requests for a device.
@@ -1431,9 +1370,7 @@ class NavienMqttClient(EventEmitter):
             device
         )
 
-    async def stop_all_periodic_tasks(
-        self, _reason: Optional[str] = None
-    ) -> None:
+    async def stop_all_periodic_tasks(self, _reason: str | None = None) -> None:
         """
         Stop all periodic request tasks.
 
